@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003-2016, John Wiegley.  All rights reserved.
+ * Copyright (c) 2003-2023, John Wiegley.  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -236,7 +236,7 @@ void amount_t::initialize()
 
     commodity_pool_t::current_pool.reset(new commodity_pool_t);
 
-    // Add time commodity conversions, so that timelog's may be parsed
+    // Add time commodity conversions, so that timelogs may be parsed
     // in terms of seconds, but reported as minutes or hours.
     if (commodity_t * commodity = commodity_pool_t::current_pool->create("s"))
       commodity->add_flags(COMMODITY_BUILTIN | COMMODITY_NOMARKET);
@@ -604,7 +604,9 @@ void amount_t::in_place_invert()
     throw_(amount_error, _("Cannot invert an uninitialized amount"));
 
   _dup();
-  mpq_inv(MP(quantity), MP(quantity));
+
+  if (sign() != 0)
+    mpq_inv(MP(quantity), MP(quantity));
 }
 
 void amount_t::in_place_round()
@@ -730,14 +732,11 @@ void amount_t::in_place_unreduce()
   }
 
   if (shifted) {
-    if (("h" == comm->symbol() || "m" == comm->symbol()) && commodity_t::time_colon_by_default) {
-      amount_t floored = tmp.floored();
-      amount_t precision = tmp - floored;
-      if (precision < 0.0) {
-        precision += 1.0;
-        floored -= 1.0;
-      }
-      tmp = floored + (precision * (comm->smaller()->number() / 100.0));
+    if (comm && ("h" == comm->symbol() || "m" == comm->symbol())
+        && commodity_t::time_colon_by_default) {
+      double truncated = trunc(tmp.to_double());
+      double precision = tmp.to_double() - truncated;
+      tmp = truncated + (precision * (comm->smaller()->number() / 100.0));
     }
 
     *this      = tmp;
@@ -972,9 +971,16 @@ namespace {
   void parse_quantity(std::istream& in, string& value)
   {
     char buf[256];
-    char c = peek_next_nonws(in);
-    READ_INTO(in, buf, 255, c,
-              std::isdigit(c) || c == '-' || c == '.' || c == ',');
+    int c = peek_next_nonws(in);
+    int max = 255;
+    char *p = buf;
+    if (c == '-') {
+      *p++ = c;
+      max--;
+      in.get();
+    }
+    READ_INTO(in, p, max, c,
+              std::isdigit(c) || c == '.' || c == ',');
 
     string::size_type len = std::strlen(buf);
     while (len > 0 && ! std::isdigit(buf[len - 1])) {
@@ -1000,10 +1006,10 @@ bool amount_t::parse(std::istream& in, const parse_flags_t& flags)
 
   commodity_t::flags_t comm_flags = COMMODITY_STYLE_DEFAULTS;
 
-  char c = peek_next_nonws(in);
+  int c = peek_next_nonws(in);
   if (c == '-') {
     negative = true;
-    in.get(c);
+    in.get();
     c = peek_next_nonws(in);
   }
 
@@ -1049,7 +1055,7 @@ bool amount_t::parse(std::istream& in, const parse_flags_t& flags)
   // Allocate memory for the amount's quantity value.  We have to
   // monitor the allocation in a unique_ptr because this function gets
   // called sometimes from amount_t's constructor; and if there is an
-  // exeception thrown by any of the function calls after this point,
+  // exception thrown by any of the function calls after this point,
   // the destructor will never be called and the memory never freed.
 
   unique_ptr<bigint_t> new_quantity;
@@ -1090,6 +1096,8 @@ bool amount_t::parse(std::istream& in, const parse_flags_t& flags)
 
   bool no_more_commas  = false;
   bool no_more_periods = false;
+  bool no_migrate_style
+    = commodity().has_flags(COMMODITY_STYLE_NO_MIGRATE);
   bool decimal_comma_style
     = (commodity_t::decimal_comma_by_default ||
        commodity().has_flags(COMMODITY_STYLE_DECIMAL_COMMA));
@@ -1173,7 +1181,7 @@ bool amount_t::parse(std::istream& in, const parse_flags_t& flags)
     // is non-NULL.
     new_quantity->add_flags(BIGINT_KEEP_PREC);
   }
-  else if (commodity_) {
+  else if (commodity_ && ! no_migrate_style) {
     commodity().add_flags(comm_flags);
 
     if (new_quantity->prec > commodity().precision())
