@@ -1,9 +1,9 @@
 /*
- * Copyright (c) 2003-2014, John Wiegley.  All rights reserved.
+ * Copyright (c) 2003-2023, John Wiegley.  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
+ * modification, are permitted provided that the following conditions are
+ * met:
  *
  * - Redistributions of source code must retain the above copyright
  *   notice, this list of conditions and the following disclaimer.
@@ -50,8 +50,8 @@
  * automatically expanded to include as many extra digits as necessary
  * to avoid losing information.
  */
-#ifndef _AMOUNT_H
-#define _AMOUNT_H
+#ifndef INCLUDED_AMOUNT_H
+#define INCLUDED_AMOUNT_H
 
 #include "utils.h"
 #include "times.h"
@@ -499,7 +499,7 @@ public:
       fits_in_long() returns true if to_long() would not lose
       precision.
 
-      to_string() returns an amount'ss "display value" as a string --
+      to_string() returns an amount's "display value" as a string --
       after rounding the value according to the commodity's default
       precision.  It is equivalent to: `round().to_fullstring()'.
 
@@ -743,16 +743,6 @@ public:
 
   bool valid() const;
 
-#if HAVE_BOOST_SERIALIZATION
-private:
-  /** Serialization. */
-
-  friend class boost::serialization::access;
-
-  template<class Archive>
-  void serialize(Archive& ar, const unsigned int /* version */);
-#endif // HAVE_BOOST_SERIALIZATION
-
   /*@}*/
 };
 
@@ -797,4 +787,4 @@ void put_amount(property_tree::ptree& pt, const amount_t& amt,
 
 } // namespace ledger
 
-#endif // _AMOUNT_H
+#endif // INCLUDED_AMOUNT_H
