@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003-2016, John Wiegley.  All rights reserved.
+ * Copyright (c) 2003-2023, John Wiegley.  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -294,62 +294,28 @@ bool commodity_t::symbol_needs_quotes(const string& symbol)
 
 void commodity_t::parse_symbol(std::istream& in, string& symbol)
 {
-  istream_pos_type pos = in.tellg();
+  std::istream::pos_type pos = in.tellg();
 
   char buf[256];
-  char c = peek_next_nonws(in);
+  int c = peek_next_nonws(in);
   if (c == '"') {
-    in.get(c);
+    in.get();
     READ_INTO(in, buf, 255, c, c != '"');
     if (c == '"')
-      in.get(c);
+      in.get();
     else
       throw_(amount_error, _("Quoted commodity symbol lacks closing quote"));
   } else {
     char * _p = buf;
-    while (_p - buf < 255 && in.good() && ! in.eof() && c != '\n') {
-      std::size_t    bytes = 0;
-      std::ptrdiff_t size  = _p - buf;
-      unsigned char  d     = static_cast<unsigned char>(c);
-
-      // Check for the start of a UTF-8 multi-byte encoded string
-      if (d >= 192 && d <= 223 && size < 254)
-        bytes = 2;
-      else if (d >= 224 && d <= 239 && size < 253)
-        bytes = 3;
-      else if (d >= 240 && d <= 247 && size < 252)
-        bytes = 4;
-      else if (d >= 248 && d <= 251 && size < 251)
-        bytes = 5;
-      else if (d >= 252 && d <= 253 && size < 250)
-        bytes = 6;
-      else if (d >= 254) // UTF-8 encoding error
-        break;
-
-      if (bytes > 0) {          // we're looking at a UTF-8 encoding
-        for (std::size_t i = 0; i < bytes; i++) {
-          in.get(c);
-          if (in.bad() || in.eof())
-            throw_(amount_error, _("Invalid UTF-8 encoding for commodity name"));
-          *_p++ = c;
-        }
-      }
-      else if (invalid_chars[static_cast<unsigned char>(c)]) {
-        break;
-      }
-      else {
-        in.get(c);
+    while (_p - buf < 255 && in.good() && ! in.eof() && ! invalid_chars[c]) {
+      c = in.get();
+      if (c == '\\') {
+        c = in.get();
         if (in.eof())
-          break;
-        if (c == '\\') {
-          in.get(c);
-          if (in.eof())
-            throw_(amount_error, _("Backslash at end of commodity name"));
-        }
-        *_p++ = c;
+          throw_(amount_error, _("Backslash at end of commodity name"));
       }
-
-      c = static_cast<char>(in.peek());
+      *_p++ = c;
+      c = in.peek();
     }
     *_p = '\0';
 
@@ -420,8 +386,8 @@ bool commodity_t::valid() const
   return true;
 }
 
-bool commodity_t::compare_by_commodity::operator()(const amount_t * left,
-                                                   const amount_t * right) const
+int commodity_t::compare_by_commodity::operator()(const amount_t * left,
+                                                  const amount_t * right) const
 {
   commodity_t& leftcomm(left->commodity());
   commodity_t& rightcomm(right->commodity());
@@ -430,71 +396,131 @@ bool commodity_t::compare_by_commodity::operator()(const amount_t * left,
   DEBUG("commodity.compare", "right symbol (" << rightcomm << ")");
 
   int cmp = leftcomm.base_symbol().compare(rightcomm.base_symbol());
-  if (cmp != 0)
-    return cmp < 0;
-
-  if (! leftcomm.has_annotation()) {
-    return rightcomm.has_annotation();
+  if (cmp != 0) {
+    DEBUG("commodity.compare", "symbol is <");
+    return cmp;
   }
-  else if (! rightcomm.has_annotation()) {
-    return ! leftcomm.has_annotation();
+
+  if (! leftcomm.has_annotation() && rightcomm.has_annotation()) {
+    DEBUG("commodity.compare", "left has no annotation, right does");
+    return -1;
+  }
+  else if (leftcomm.has_annotation() && ! rightcomm.has_annotation()) {
+    DEBUG("commodity.compare", "right has no annotation, left does");
+    return 1;
+  }
+  else if (! leftcomm.has_annotation() && ! rightcomm.has_annotation()) {
+    DEBUG("commodity.compare", "there are no annotations, commodities match");
+    return 0;
   }
-  else {
-    annotated_commodity_t& aleftcomm(static_cast<annotated_commodity_t&>(leftcomm));
-    annotated_commodity_t& arightcomm(static_cast<annotated_commodity_t&>(rightcomm));
 
-    if (! aleftcomm.details.price && arightcomm.details.price)
-      return true;
-    if (aleftcomm.details.price && ! arightcomm.details.price)
-      return false;
+  annotated_commodity_t& aleftcomm(static_cast<annotated_commodity_t&>(leftcomm));
+  annotated_commodity_t& arightcomm(static_cast<annotated_commodity_t&>(rightcomm));
 
-    if (aleftcomm.details.price && arightcomm.details.price) {
-      amount_t leftprice(*aleftcomm.details.price);
-      amount_t rightprice(*arightcomm.details.price);
+  if (! aleftcomm.details.price && arightcomm.details.price) {
+    DEBUG("commodity.compare", "left has no price, right does");
+    return -1;
+  }
+  if (aleftcomm.details.price && ! arightcomm.details.price) {
+    DEBUG("commodity.compare", "right has no price, left does");
+    return 1;
+  }
 
-      if (leftprice.commodity() == rightprice.commodity()) {
-        return (leftprice - rightprice).sign() < 0;
-      } else {
-        // Since we have two different amounts, there's really no way
-        // to establish a true sorting order; we'll just do it based
-        // on the numerical values.
-        leftprice.clear_commodity();
-        rightprice.clear_commodity();
-        return (leftprice - rightprice).sign() < 0;
+  if (aleftcomm.details.price && arightcomm.details.price) {
+    amount_t leftprice(*aleftcomm.details.price);
+    amount_t rightprice(*arightcomm.details.price);
+
+    if (leftprice.commodity() != rightprice.commodity()) {
+      // Since we have two different amounts, there's really no way to
+      // establish a true sorting order; we'll just do it based on the
+      // numerical values, before falling back to comparing the prices
+      // with their original commodity.
+      amount_t leftpricenumeric(leftprice);
+      amount_t rightpricenumeric(rightprice);
+      leftpricenumeric.clear_commodity();
+      rightpricenumeric.clear_commodity();
+      DEBUG("commodity.compare",
+            "both have price, commodities don't match, recursing");
+      int cmp2 = commodity_t::compare_by_commodity()(&leftpricenumeric, &rightpricenumeric);
+      if (cmp2 != 0) {
+        DEBUG("commodity.compare", "recursion found a disparity");
+        return cmp2;
+      }
+      DEBUG("commodity.compare", "recursion found no difference, comparing prices with commodity");
+      return commodity_t::compare_by_commodity()(&leftprice, &rightprice);
+    } else {
+      if (leftprice < rightprice) {
+        DEBUG("commodity.compare", "left price is less");
+        return -1;
+      }
+      else if (leftprice > rightprice) {
+        DEBUG("commodity.compare", "left price is more");
+        return 1;
       }
     }
+  }
 
-    if (! aleftcomm.details.date && arightcomm.details.date)
-      return true;
-    if (aleftcomm.details.date && ! arightcomm.details.date)
-      return false;
+  if (! aleftcomm.details.date && arightcomm.details.date) {
+    DEBUG("commodity.compare", "left has no date, right does");
+    return -1;
+  }
+  if (aleftcomm.details.date && ! arightcomm.details.date) {
+    DEBUG("commodity.compare", "right has no date, left does");
+    return 1;
+  }
 
-    if (aleftcomm.details.date && arightcomm.details.date) {
-      gregorian::date_duration diff =
-        *aleftcomm.details.date - *arightcomm.details.date;
-      return diff.is_negative();
+  if (aleftcomm.details.date && arightcomm.details.date) {
+    gregorian::date_duration diff =
+      *aleftcomm.details.date - *arightcomm.details.date;
+    DEBUG("commodity.compare", "both have dates, comparing on difference");
+    if (diff.is_negative()) {
+      DEBUG("commodity.compare", "dates differ");
+      return -1;
     }
 
-    if (! aleftcomm.details.tag && arightcomm.details.tag)
-      return true;
-    if (aleftcomm.details.tag && ! arightcomm.details.tag)
-      return false;
-
-    if (aleftcomm.details.tag && arightcomm.details.tag)
-      return *aleftcomm.details.tag < *arightcomm.details.tag;
-
-    if (! aleftcomm.details.value_expr && arightcomm.details.value_expr)
-      return true;
-    if (aleftcomm.details.value_expr && ! arightcomm.details.value_expr)
-      return false;
-
-    if (aleftcomm.details.value_expr && arightcomm.details.value_expr)
-      return (aleftcomm.details.value_expr->text() <
-              arightcomm.details.value_expr->text());
-
-    assert(false);
-    return true;
+    gregorian::date_duration diff2 =
+      *arightcomm.details.date - *aleftcomm.details.date;
+    if (diff2.is_negative()) {
+      DEBUG("commodity.compare", "dates differ");
+      return 1;
+    }
   }
+
+  if (! aleftcomm.details.tag && arightcomm.details.tag) {
+    DEBUG("commodity.compare", "left has no tag, right does");
+    return -1;
+  }
+  if (aleftcomm.details.tag && ! arightcomm.details.tag) {
+    DEBUG("commodity.compare", "right has no tag, left does");
+    return 1;
+  }
+
+  if (aleftcomm.details.tag && arightcomm.details.tag) {
+    DEBUG("commodity.compare", "both have tags, comparing lexically");
+    if (*aleftcomm.details.tag < *arightcomm.details.tag)
+      return -1;
+    else if (*aleftcomm.details.tag > *arightcomm.details.tag)
+      return 1;
+  }
+
+  if (! aleftcomm.details.value_expr && arightcomm.details.value_expr) {
+    DEBUG("commodity.compare", "left has no value expr, right does");
+    return -1;
+  }
+  if (aleftcomm.details.value_expr && ! arightcomm.details.value_expr) {
+    DEBUG("commodity.compare", "right has no value expr, left does");
+    return 1;
+  }
+
+  if (aleftcomm.details.value_expr && arightcomm.details.value_expr) {
+    DEBUG("commodity.compare", "both have value exprs, comparing text reprs");
+    return (aleftcomm.details.value_expr->text() <
+            arightcomm.details.value_expr->text());
+  }
+
+  DEBUG("commodity.compare", "the two are incomparable, which should never happen");
+  assert(false);
+  return -1;
 }
 
 void put_commodity(property_tree::ptree& st, const commodity_t& comm,
