@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003-2016, John Wiegley.  All rights reserved.
+ * Copyright (c) 2003-2023, John Wiegley.  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -35,6 +35,8 @@
 #include "parser.h"
 #include "scope.h"
 
+#include <boost/smart_ptr/scoped_ptr.hpp>
+
 namespace ledger {
 
 expr_t::expr_t() : base_type()
@@ -94,9 +96,9 @@ void expr_t::parse(std::istream& in, const parse_flags_t& flags,
                    const optional<string>& original_string)
 {
   parser_t parser;
-  istream_pos_type start_pos = in.tellg();
+  std::istream::pos_type start_pos = in.tellg();
   ptr = parser.parse(in, flags, original_string);
-  istream_pos_type end_pos = in.tellg();
+  std::istream::pos_type end_pos = in.tellg();
 
   if (original_string) {
     set_text(*original_string);
@@ -290,10 +292,10 @@ value_t source_command(call_scope_t& args)
     in = &std::cin;
   }
 
-  symbol_scope_t   file_locals(args);
-  std::size_t      linenum = 0;
-  char             buf[4096];
-  istream_pos_type pos;
+  symbol_scope_t         file_locals(args);
+  std::size_t            linenum = 0;
+  char                   buf[4096];
+  std::istream::pos_type pos;
 
   while (in->good() && ! in->eof()) {
     pos = in->tellg();
