@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003-2016, John Wiegley.  All rights reserved.
+ * Copyright (c) 2003-2023, John Wiegley.  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -152,7 +152,7 @@ void item_t::parse_tags(const char * p,
     if (const char * b = std::strchr(p, '[')) {
       if (*(b + 1) != '\0' &&
           (std::isdigit(*(b + 1)) || *(b + 1) == '=')) {
-        if (const char * e = std::strchr(p, ']')) {
+        if (const char * e = std::strchr(b, ']')) {
           char buf[256];
           std::strncpy(buf, b + 1, static_cast<std::size_t>(e - b - 1));
           buf[e - b - 1] = '\0';
@@ -198,7 +198,7 @@ void item_t::parse_tags(const char * p,
       tag = string(q, len - index);
 
       string_map::iterator i;
-      string field(p + len + index);
+      string field(p + (q - buf.get()) + len);
       trim(field);
       if (by_value) {
         bind_scope_t bound_scope(scope, *this);
@@ -369,7 +369,7 @@ namespace {
   }
 
   value_t get_addr(item_t& item) {
-    return long(&item);
+    return long(reinterpret_cast<intptr_t>(&item));
   }
 
   value_t get_depth(item_t&) {
