@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003-2016, John Wiegley.  All rights reserved.
+ * Copyright (c) 2003-2023, John Wiegley.  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -42,6 +42,11 @@ namespace {
   {
     char buf[128];
     char * p = buf;
+
+    if (name.length() > 127) {
+        throw_(option_error, _f("Illegal option --%1%") % name);
+    }
+
     foreach (char ch, name) {
       if (ch == '-')
         *p++ = '_';
@@ -90,7 +95,7 @@ namespace {
       if (name[0] == '-')
         add_error_context(_f("While parsing option '%1%'") % name);
       else
-        add_error_context(_f("While parsing environent variable '%1%'") % name);
+        add_error_context(_f("While parsing environment variable '%1%'") % name);
       throw;
     }
   }
