@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003-2016, John Wiegley.  All rights reserved.
+ * Copyright (c) 2003-2023, John Wiegley.  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -106,8 +106,10 @@ date_t post_t::primary_date() const
     return xdata_->date;
 
   if (! _date) {
-    assert(xact);
-    return xact->date();
+    if (xact)
+      return xact->date();
+    else
+      return CURRENT_DATE();
   }
   return *_date;
 }
@@ -120,12 +122,22 @@ optional<date_t> post_t::aux_date() const
   return date;
 }
 
-string post_t::payee() const
+string post_t::payee_from_tag() const
 {
   if (optional<value_t> post_payee = get_tag(_("Payee")))
     return post_payee->as_string();
   else
-    return xact->payee;
+    return "";
+}
+
+string post_t::payee() const
+{
+  if (_payee)
+    return *_payee;
+
+  string post_payee = payee_from_tag();
+
+  return post_payee != "" ? post_payee : xact ? xact->payee : "";
 }
 
 namespace {
@@ -713,13 +725,16 @@ void put_post(property_tree::ptree& st, const post_t& post)
   if (post._date_aux)
     put_date(st.put("aux-date", ""), *post._date_aux);
 
+  if (post.payee_from_tag() != "")
+    st.put("payee", post.payee_from_tag());
+
   if (post.account) {
     property_tree::ptree& t(st.put("account", ""));
 
     std::ostringstream buf;
-    buf.width(sizeof(unsigned long) * 2);
+    buf.width(sizeof(intptr_t) * 2);
     buf.fill('0');
-    buf << std::hex << reinterpret_cast<unsigned long>(post.account);
+    buf << std::hex << reinterpret_cast<intptr_t>(post.account);
 
     t.put("<xmlattr>.ref", buf.str());
     t.put("name", post.account->fullname());
