@@ -3,7 +3,7 @@
 # convert.py: This script converts a Boost.Test unit test into an
 # equivalent Python unit test.
 #
-# Copyright (c) 2003-2016, John Wiegley.  All rights reserved.
+# Copyright (c) 2003-2023, John Wiegley.  All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions are
@@ -36,9 +36,9 @@ import re
 import sys
 import os
 
-source = os.path.abspath(sys.argv[1])
+source = os.path.realpath(sys.argv[1])
 base   = os.path.splitext(source)[0]
-target = os.path.abspath(sys.argv[2])
+target = os.path.realpath(sys.argv[2])
 
 dirname = os.path.dirname(target)
 if not os.path.isdir(dirname):
