@@ -7,8 +7,8 @@ total_gbp = ledger.Amount("0.00 GBP")
 total = ledger.Amount("0.00 EUR")
 
 for post in ledger.read_journal("test/regress/78AB4B87.dat").query("^income:"):
-    print post.amount
-    print post.amount.commodity
+    print(post.amount)
+    print(post.amount.commodity)
     if post.amount.commodity == "EUR":
         total_eur += post.amount
     elif post.amount.commodity == "GBP":
@@ -16,12 +16,12 @@ for post in ledger.read_journal("test/regress/78AB4B87.dat").query("^income:"):
 
     a = post.amount.value(eur, post.date)
     if a:
-        print "Total is presently: (%s)" % total
-        print "Converted to EUR:   (%s)" % a
+        print("Total is presently: (%s)" % total)
+        print("Converted to EUR:   (%s)" % a)
         total += a
-        print "Total is now:       (%s)" % total
+        print("Total is now:       (%s)" % total)
     else:
-        print "Cannot convert '%s'" % post.amount
-    print
+        print("Cannot convert '%s'" % post.amount)
+    print()
 
-print total
+print(total)
