@@ -6,6 +6,10 @@
 
 #include "value.h"
 
+#if defined(_WIN32) || defined(__CYGWIN__)
+#include "strptime.h"
+#endif
+
 using namespace ledger;
 
 struct value_fixture {
